@@ -1,11 +1,11 @@
 package Test::File::IsSorted;
-$Test::File::IsSorted::VERSION = '0.0.5';
+$Test::File::IsSorted::VERSION = '0.0.6';
 use strict;
 use warnings;
 
 use parent 'Test::Builder::Module';
 
-use List::Util qw/ all /;
+use List::Util 1.34 qw/ all /;
 use File::IsSorted ();
 
 my $CLASS = __PACKAGE__;
@@ -40,7 +40,7 @@ Test::File::IsSorted - test files for being lexicographical sorted.
 
 =head1 VERSION
 
-version 0.0.5
+version 0.0.6
 
 =head1 SYNOPSIS
 
@@ -86,14 +86,6 @@ L<https://metacpan.org/release/File-IsSorted>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-IsSorted>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -102,14 +94,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-IsSorted>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-IsSorted>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
